SLCWATrainingLoop
=================

.. currentmodule:: pykeen.training

.. autoclass:: SLCWATrainingLoop
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~SLCWATrainingLoop.loss_blacklist

   .. rubric:: Attributes Documentation

   .. autoattribute:: loss_blacklist
